# Event sourcing helpers
Python helpers for practicing the event sourcing pattern using DDD.

[![codecov](https://codecov.io/gh/fyndiq/eventsourcing_helpers/branch/master/graph/badge.svg)](https://codecov.io/gh/fyndiq/eventsourcing_helpers)
